==> OpenHantek6022-2.12.tar.gz: OpenHantek-OpenHantek6022-601663c/openhantek/src/configdialog/DsoConfigColorsPage.h <==
// SPDX-License-Identifier: GPL-2.0+

#include <QWidget>

#include "settings.h"

#include <QCheckBox>
#include <QComboBox>
#include <QDoubleSpinBox>
#include <QGridLayout>
#include <QGroupBox>
#include <QHBoxLayout>
#include <QLabel>
#include <QSpinBox>
#include <QVBoxLayout>

#include "colorbox.h"

////////////////////////////////////////////////////////////////////////////////
/// \class DsoConfigColorsPage                                     configpages.h
/// \brief Config page for the colors.
class DsoConfigColorsPage : public QWidget {
    Q_OBJECT

  public:
    DsoConfigColorsPage(DsoSettings *settings, QWidget *parent = 0);

  public slots:
    void saveSettings();

  private:
    DsoSettings *settings;

    QVBoxLayout *mainLayout;

    QGroupBox *colorsGroup;
    QGridLayout *colorsLayout;

    QLabel *screenColorsLabel, *printColorsLabel;
    QLabel *axesLabel, *backgroundLabel, *borderLabel, *gridLabel, *markersLabel, *textLabel;
    ColorBox *axesColorBox, *backgroundColorBox, *borderColorBox, *gridColorBox, *markersColorBox, *textColorBox;

    ColorBox *printAxesColorBox, *printBackgroundColorBox, *printBorderColorBox, *printGridColorBox,
        *printMarkersColorBox, *printTextColorBox;

    QLabel *graphLabel;

    QLabel *screenChannelLabel, *screenSpectrumLabel, *printChannelLabel, *printSpectrumLabel;
    std::vector<QLabel *> colorLabel;
    std::vector<ColorBox *> screenChannelColorBox;
    std::vector<ColorBox *> screenSpectrumColorBox;
    std::vector<ColorBox *> printChannelColorBox;
    std::vector<ColorBox *> printSpectrumColorBox;
};

==> OpenHantek6022-3.2.4.tar.gz: OpenHantek-OpenHantek6022-018497c/openhantek/src/configdialog/DsoConfigColorsPage.h <==
// SPDX-License-Identifier: GPL-2.0+

#include <QWidget>

#include <QCheckBox>
#include <QComboBox>
#include <QDoubleSpinBox>
#include <QGridLayout>
#include <QGroupBox>
#include <QHBoxLayout>
#include <QLabel>
#include <QSpinBox>
#include <QVBoxLayout>

#include <QDebug>

#include "colorbox.h"
#include "dsosettings.h"


////////////////////////////////////////////////////////////////////////////////
/// \class DsoConfigColorsPage                                     configpages.h
/// \brief Config page for the colors.
class DsoConfigColorsPage : public QWidget {
    Q_OBJECT

  public:
    DsoConfigColorsPage( DsoSettings *settings, QWidget *parent = nullptr );

  public slots:
    void saveSettings();

  private:
    DsoSettings *settings;

    QVBoxLayout *mainLayout;

    QGroupBox *colorsGroup;
    QGridLayout *colorsLayout;

    QLabel *screenColorsLabel, *printColorsLabel;
    QLabel *axesLabel, *backgroundLabel, *borderLabel, *gridLabel, *markersLabel, *textLabel;
    ColorBox *axesColorBox, *backgroundColorBox, *borderColorBox, *gridColorBox, *markersColorBox, *textColorBox;

    ColorBox *printAxesColorBox, *printBackgroundColorBox, *printBorderColorBox, *printGridColorBox, *printMarkersColorBox,
        *printTextColorBox;

    QLabel *horizontalLine;

    QLabel *screenChannelLabel, *screenSpectrumLabel, *printChannelLabel, *printSpectrumLabel;
    std::vector< QLabel * > colorLabel;
    std::vector< ColorBox * > screenChannelColorBox;
    std::vector< ColorBox * > screenSpectrumColorBox;
    std::vector< ColorBox * > printChannelColorBox;
    std::vector< ColorBox * > printSpectrumColorBox;
    QCheckBox *screenColorCheckBox;
    QLabel *fontSizeLabel;
    QSpinBox *fontSizeSpinBox;
    QCheckBox *styleFusionCheckBox;
};
